==> jc-1.4.0.tar.gz: java/lang/ClassNotFoundException.h <==
// public class java.lang.ClassNotFoundException

// class file dependencies
// @dep_class 1f925cf50bfc0d6c java_lang_ClassNotFoundException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_ClassNotFoundException_H_
#define _JC_java_lang_ClassNotFoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_ClassNotFoundException$sub_refs	_jc_java_lang_ClassNotFoundException$sub_refs;
typedef struct _jc_java_lang_ClassNotFoundException$sub_nonrefs	_jc_java_lang_ClassNotFoundException$sub_nonrefs;
typedef struct _jc_java_lang_ClassNotFoundException$refs	_jc_java_lang_ClassNotFoundException$refs;
typedef struct _jc_java_lang_ClassNotFoundException$nonrefs	_jc_java_lang_ClassNotFoundException$nonrefs;
typedef struct _jc_java_lang_ClassNotFoundException$object	_jc_java_lang_ClassNotFoundException$object;

typedef struct _jc_java_lang_ClassNotFoundException$fields_struct	_jc_java_lang_ClassNotFoundException$fields_struct;
typedef const struct _jc_java_lang_ClassNotFoundException$vmethods	_jc_java_lang_ClassNotFoundException$vmethods;
typedef const struct _jc_java_lang_ClassNotFoundException$vtable	_jc_java_lang_ClassNotFoundException$vtable;
typedef const struct _jc_java_lang_ClassNotFoundException$vtype	_jc_java_lang_ClassNotFoundException$vtype;

// Class fields structure
struct _jc_java_lang_ClassNotFoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ClassNotFoundException$fields_struct _jc_java_lang_ClassNotFoundException$class_fields;

// Constructors
extern void _jc_java_lang_ClassNotFoundException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *);
extern void _jc_java_lang_ClassNotFoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_ClassNotFoundException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ClassNotFoundException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *);
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ClassNotFoundException$method$getException$74d033e489a87383(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ClassNotFoundException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_ClassNotFoundException$method_info$getException$74d033e489a87383;

// Virtual methods structure
struct _jc_java_lang_ClassNotFoundException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *);
	struct _jc_java_lang_Throwable$object	*(*getException$74d033e489a87383)(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *);
};

// Vtable
struct _jc_java_lang_ClassNotFoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_ClassNotFoundException$vmethods	java_lang_ClassNotFoundException;
};

// Vtype
struct _jc_java_lang_ClassNotFoundException$vtype {
	_jc_type			type;
	_jc_java_lang_ClassNotFoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassNotFoundException$sub_refs {
	struct _jc_java_lang_Throwable$object	*ex;
};

// Reference instance fields (object)
struct _jc_java_lang_ClassNotFoundException$refs {
    _jc_java_lang_ClassNotFoundException$sub_refs	java_lang_ClassNotFoundException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassNotFoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassNotFoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_ClassNotFoundException$sub_nonrefs	java_lang_ClassNotFoundException;
};

// Object instance structure
struct _jc_java_lang_ClassNotFoundException$object {
	_jc_java_lang_ClassNotFoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassNotFoundException$vtype	*vtype;
	_jc_java_lang_ClassNotFoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassNotFoundException$vtype _jc_java_lang_ClassNotFoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassNotFoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassNotFoundException$class_object;

#endif	/* _JC_java_lang_ClassNotFoundException_H_ */

==> jc-1.4.6.tar.gz: java/lang/ClassNotFoundException.h <==
// public class java.lang.ClassNotFoundException

// class file dependencies
// @dep_class 1f925cf50bfc0d6c java_lang_ClassNotFoundException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_lang_ClassNotFoundException_H_
#define _JC_java_lang_ClassNotFoundException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_ClassNotFoundException$sub_refs	_jc_java_lang_ClassNotFoundException$sub_refs;
typedef struct _jc_java_lang_ClassNotFoundException$sub_nonrefs	_jc_java_lang_ClassNotFoundException$sub_nonrefs;
typedef struct _jc_java_lang_ClassNotFoundException$refs	_jc_java_lang_ClassNotFoundException$refs;
typedef struct _jc_java_lang_ClassNotFoundException$nonrefs	_jc_java_lang_ClassNotFoundException$nonrefs;
typedef struct _jc_java_lang_ClassNotFoundException$object	_jc_java_lang_ClassNotFoundException$object;

typedef struct _jc_java_lang_ClassNotFoundException$fields_struct	_jc_java_lang_ClassNotFoundException$fields_struct;
typedef const struct _jc_java_lang_ClassNotFoundException$vmethods	_jc_java_lang_ClassNotFoundException$vmethods;
typedef const struct _jc_java_lang_ClassNotFoundException$vtable	_jc_java_lang_ClassNotFoundException$vtable;
typedef const struct _jc_java_lang_ClassNotFoundException$vtype	_jc_java_lang_ClassNotFoundException$vtype;

// Class fields structure
struct _jc_java_lang_ClassNotFoundException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ClassNotFoundException$fields_struct _jc_java_lang_ClassNotFoundException$class_fields;

// Constructors
extern void _jc_java_lang_ClassNotFoundException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ClassNotFoundException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ClassNotFoundException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ClassNotFoundException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Throwable$object *_jc_java_lang_ClassNotFoundException$method$getException$74d033e489a87383(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ClassNotFoundException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_lang_ClassNotFoundException$method_info$getException$74d033e489a87383;

// Virtual methods structure
struct _jc_java_lang_ClassNotFoundException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Throwable$object	*(*getException$74d033e489a87383)(_jc_env *, struct _jc_java_lang_ClassNotFoundException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ClassNotFoundException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_ClassNotFoundException$vmethods	java_lang_ClassNotFoundException;
};

// Vtype
struct _jc_java_lang_ClassNotFoundException$vtype {
	_jc_type			type;
	_jc_java_lang_ClassNotFoundException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ClassNotFoundException$sub_refs {
	struct _jc_java_lang_Throwable$object	*ex;
};

// Reference instance fields (object)
struct _jc_java_lang_ClassNotFoundException$refs {
    _jc_java_lang_ClassNotFoundException$sub_refs	java_lang_ClassNotFoundException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ClassNotFoundException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ClassNotFoundException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_ClassNotFoundException$sub_nonrefs	java_lang_ClassNotFoundException;
};

// Object instance structure
struct _jc_java_lang_ClassNotFoundException$object {
	_jc_java_lang_ClassNotFoundException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ClassNotFoundException$vtype	*vtype;
	_jc_java_lang_ClassNotFoundException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ClassNotFoundException$vtype _jc_java_lang_ClassNotFoundException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ClassNotFoundException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ClassNotFoundException$class_object;

#endif	/* _JC_java_lang_ClassNotFoundException_H_ */
